%             spVTVmProc.m
% Second order TVT-Splitting method
% fT, fV: the vectorfields
% x0: initial conditions
% t0, tf: time span
% N: divisions of the time interval (timestep h=(tf-t0)/N)
function [t q p] = spVTVmProc(fT,fVm,t0,tf,q0,p0,N)
 h = (tf-t0)/N;

np=3;
y1=0.1859353996846055; y2=0.0731969797858114; y3=-0.1576624269298081;
y=[y1,y2,y3];
z1=0.8749306155955435; z2=-0.2371066801510219; z3=-0.5363539829039128;
z=[z1,z2,z3];
 
 yh=h*y; zh=h*z;
 t=t0:h:tf;  q=q0';q1=q0; p=p0'; p1=p0;
% Pre-processor
    for j=1:np;
   [fV1 fV3]= fVm(q1);
     p1 = p1 - yh(j)*fV1;
     q1 = q1 + zh(j)*fT(p1);
    end
% Kernel
 fT0 = fT(p1);
 for i=1:N;
   q1 = q1 + (h/2)*fT0;
   [fV1 fV3]= fVm(q1);
   p1 = p1 - h*fV1 - (h^3/24)*fV3;
   fT0 = fT(p1);
   q1 = q1 + (h/2)*fT0;

% Post-processor
   qq1=q1;  pp1=p1;
    for j=np:-1:1;
     qq1 = qq1 - zh(j)*fT(pp1);
     [fV1 fV3]= fVm(qq1);
   pp1 = pp1 + yh(j)*fV1;
    end
   q = [q ; qq1' ];
   p = [p ; pp1' ];
 end
